Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(699)

Unified Diff: remoting/host/constants.h

Issue 10873050: [Chromoting] Hook up host talkgadget policy checks. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/host/constants.h
diff --git a/remoting/host/constants.h b/remoting/host/constants.h
index 54aa2280c657a5ec1fdc210838a88f1c20071179..97f077ba7c646573a2f04d3a188a8907ba76c114 100644
--- a/remoting/host/constants.h
+++ b/remoting/host/constants.h
@@ -9,10 +9,13 @@
namespace remoting {
// This is the default prefix that is prepended to ".talkgadget.google.com"
// to form the complete talkgadget domain name. Policy settings allow admins
// to change the prefix that is used.
-extern const char kDefaultTalkGadgetPrefix[];
+extern const char kDefaultHostTalkGadgetPrefix[];
+
+// The talkgadget URL.
+extern const char kTalkGadgetURL[];
// Known host exit codes.
// Please keep this enum in sync with:
@@ -9,10 +9,13 @@
namespace remoting {
-// This is the default prefix that is prepended to ".talkgadget.google.com"
-// to form the complete talkgadget domain name. Policy settings allow admins
+// This is the default prefix that is prepended to the kTalkGadgetURL to form
+// the complete talkgadget URL used by the host. Policy settings allow admins
// to change the prefix that is used.

Powered by Google App Engine
This is Rietveld 408576698